<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] = (@$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] ?: array()) + array("_9c050c786fc87170cbb84fc6a8" . "b13cb6" => base64_decode("YXR0YWNobWVudC" . "0="), "_6e1c717cf3cbf1a" . "f982ed74d4336b7f" . "1" => base64_decode("Ym9keS1o" . "dG1s"), "_956cd32298" . "a229f9768f1" . "096f077ace3" => base64_decode("Ym9keS1wbGFp" . "bg=="), "_44e986c04f41a08b56a383c7b3a8" . "8ee2" => base64_decode("c2VuZGV" . "y"), "_1d6c68a026" . "2e8fa0bed12" . "15b7224a98e" => base64_decode("cmVjaXB" . "pZW50"), "_8c575917cbaed" . "f1e7efae849394" . "02bff" => base64_decode("U3Vi" . "amVj" . "dA=="), "_618a4aeb9" . "fecc4592a4" . "521f34876f" . "a29" => base64_decode("ZnJvbQ=" . "="), "_f39f5346e313e4dd1" . "ac3a7bd8032beda" => base64_decode("c3Vic3RyX2NvbXBhcm" . "U="), "_a1e707d02a236dadebd15a45e65eb" . "db6" => base64_decode("YXR0YWNobWVudC1jb3V" . "udA=="), "_f589476007fa133f457" . "c3ef29ddfa566" => base64_decode("VG8" . "="), "_d706c160e45bf7434fff82a5976f0e1" . "9" => base64_decode("YXJyYXlfa2V5cw" . "=="), "_97ea09a7faf27c52c6eff69773df" . "1d8a" => base64_decode("dGltZXN0YW" . "1w"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_d706c160e" . "45bf7434ff" . "f82a5976f0" . "e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_a1e707d02a236dad" . "ebd15a45e65ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_f39f5346e313e4dd1ac3a7b" . "d8032beda"]($key, $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_9c050c786fc87170cbb84fc6a8b13c" . "b6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_1d6c68a0262e8fa0bed1" . "215b7224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_618a4aeb9fecc4592a45" . "21f34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_f589476007fa133f45" . "7c3ef29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_8c575917cbaedf1e7ef" . "ae84939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_6e1c717cf3cbf1af982" . "ed74d4336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_956cd32298a229f9768" . "f1096f077ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_97ea09a7faf27c52c" . "6eff69773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_44e986c04f41a08b56a38" . "3c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}