<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array("_618a4aeb9fecc4592a4521f34876" . "fa29" => base64_decode("ZnJvbQ" . "=="), "_e608e5b5c4c" . "34a67ba97ef8" . "4c1e16199" => base64_decode("Jw=" . "="), "_5d40a2cf1c525fb252bf5599e339fd" . "d0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRpZmllZCBmb3IgbWFpbDsgc3Vi" . "amVjdCAn"), "project_i" . "d" => base64_decode("cHJv" . "amVj" . "dF9p" . "ZA=="), "_67a0d624aebcceb0" . "abd5ce56a53ff06f" => base64_decode("ZGF0" . "ZQ=="), "_c35473364fa7a050299058f332ec29" . "c1" => base64_decode("ZXhjZX" . "B0aW9u"), "_460e1aeb31" . "13a1676ce59" . "a8f40431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1" . "haWwgZm9yIGluZm9jYXB0dXJlIH" . "Byb2plY3Q="), "_bfda889b74ea5" . "61b14325e30e7d" . "75426" => base64_decode("Ym9keV9odG" . "1s"), "_376d30c40857357a4d" . "4cbb1ffaa25817" => base64_decode("dG" . "8="), "_03b1f0cee835582d1158dc" . "e2678b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCB" . "yZWNlaXZlZCBzdWJzY3JpYmVy"), "_f656816961e85738061" . "41c558b184fe2" => base64_decode("c3ViamV" . "jdA=="), "_a3d82c5df3" . "8e194c9c73e" . "3ccb4223bbc" => base64_decode("ZW1haWxf" . "ZGF0YQ=="), "_9b16fa2683095e67d7" . "c8b265a8081d0b" => base64_decode("TWFpbFJlY2VpdmVkRXZlbnRSZWNlaXZlcg=" . "="), "_ced92d7b391285c8a26846f1f4bd" . "3128" => base64_decode("Ym9" . "keV" . "90Z" . "Xh0"));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_9b16fa2683095e67d7c8b26" . "5a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_03b1f0cee835582d1158dce2678" . "b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_5d40a2cf1c525fb252bf5" . "599e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_e608e5b5c4c34a67ba97ef84c1e161" . "99"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_618a4aeb9fecc4592a4521f3487" . "6fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_376d30c40857357a4" . "d4cbb1ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_f656816961e8573806141c558b1" . "84fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_ced92d7b391285c8a26846" . "f1f4bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_bfda889b7" . "4ea561b143" . "25e30e7d75" . "426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_67a0d624aebcce" . "b0abd5ce56a53ff" . "06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_460e1aeb31" . "13a1676ce59" . "a8f40431d5c"], [$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["project_i" . "d"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_a3d82c5df38e194c9c73e3ccb4223bb" . "c"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_c35473364fa7a050299058f33" . "2ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}